Enum Source 

pub enum Source {
    Program(Program),
    Library(Library),
}
This structure is used to represent parsing arbitrary AirScript files which may or may not contain a root module.

All of the details described in the documentation for Program and Library apply to their respective variants here.

Variants



Program(Program)

The source code which was parsed produced a valid Program, i.e. it contained a root module, and optionally, one or more library modules.



Library(Library)

The source code which was parsed did not contain a root module, and so does not constitute a valid Program on its own. However, we were still able to produce a library of modules, which can be combined with a root module to produce a Program later.