TraceBinding

Struct TraceBinding 

pub struct TraceBinding {
    pub span: SourceSpan,
    pub name: Option<Identifier>,
    pub segment: TraceSegmentId,
    pub offset: usize,
    pub size: usize,
    pub ty: Type,
}
TraceBinding is used to represent one or more columns in the execution trace that are bound to a name. For single columns, the size is 1. For groups, the size is the number of columns in the group. The offset is the column index in the trace where the first column of the binding starts.

Fields

span: SourceSpanname: Option<Identifier>

The name of this binding, if applicable

segment: TraceSegmentId

The id of the segment to which this binding belongs

offset: usize

The offset to the first column of the segment which is bound by this binding

size: usize

The number of columns which are bound

ty: Type

The effective type of this binding

Implementations

Source

impl TraceBinding

pub const fn new( span: SourceSpan, name: Identifier, segment: TraceSegmentId, offset: usize, size: usize, ty: Type, ) -> Self

Creates a new trace binding.

pub fn ty(&self) -> Type

Returns a Type that describes what type of value this binding represents

pub fn is_scalar(&self) -> bool

pub fn access( &self, access_type: AccessType, ) -> Result<Self, InvalidAccessError>

Derive a new TraceBinding derived from the current one given an AccessType