Module visit

Module visit 

This module provides infrastructure for the visitor pattern over the AirScript AST

Implementations of VisitMut need only provide implementations of trait functions for the specific AST nodes which they are interested in, or which provide important context. By default, with no trait functions overridden, a visitor will simply traverse the AST top-down. When you override one of the trait functions, it is up to the implementation to drive the visitor down to children of the corresponding node type, if desired. For that purpose, this module exposes a number of visit_mut_* functions which can be called to perform the default visitor traversal for that node.

Traits

VisitMut
This trait represents a mutable visitor over the AST.

Functions

visit_mut_access_type
visit_mut_binary_expr
visit_mut_bounded_symbol_access
visit_mut_bus
visit_mut_bus_operation
visit_mut_call
visit_mut_const_symbol_access
visit_mut_constant
visit_mut_evaluator_function
visit_mut_evaluator_trace_binding
visit_mut_evaluator_trace_segment
visit_mut_expr
visit_mut_function
visit_mut_identifier
visit_mut_import
visit_mut_let
visit_mut_list_comprehension
visit_mut_module
visit_mut_periodic_column
visit_mut_public_input
visit_mut_range_bound
visit_mut_resolvable_identifier
visit_mut_scalar_expr
visit_mut_statement
visit_mut_statement_block
visit_mut_symbol_access
visit_mut_trace_binding
visit_mut_trace_segment
visit_mut_typed_identifier