pub enum ResolvableIdentifier {
Local(Identifier),
Global(Identifier),
Resolved(QualifiedIdentifier),
Unresolved(NamespacedIdentifier),
}Expand description
Represents an identifier which requires name resolution at some stage during lowering.
Variants
Local(Identifier)
This identifier is resolved to a local binding (i.e. function parameter or let-bound var)
Global(Identifier)
This identifier is resolved to a global binding
Resolved(QualifiedIdentifier)
This identifier is resolved to a non-local item (i.e. module-level declaration or imported item)
Unresolved(NamespacedIdentifier)
This identifier is not yet resolved or is undefined in the current scope
Implementations
Sourceimpl ResolvableIdentifier
impl ResolvableIdentifier
Sourcepub fn is_resolved(&self) -> bool
pub fn is_resolved(&self) -> bool
Returns true if this identifier has been resolved locally or otherwise
Sourcepub fn is_builtin(&self) -> bool
pub fn is_builtin(&self) -> bool
Returns true if this identifier refers to a known builtin function
Sourcepub fn module(&self) -> Option<ModuleId>
pub fn module(&self) -> Option<ModuleId>
The module to which this identifier is resolved
For locally-resolved identifiers, this returns None, same as
unresolved identifiers, check is_resolved to distinguish between
resolved/unresolved states
Sourcepub fn namespaced(&self) -> NamespacedIdentifier
pub fn namespaced(&self) -> NamespacedIdentifier
Obtains a NamespacedIdentifier from this identifier
Sourcepub fn resolved(&self) -> Option<QualifiedIdentifier>
pub fn resolved(&self) -> Option<QualifiedIdentifier>
Gets the QualifiedIdentifier if this identifier is of type Resolved