pub enum Source {
Program(Program),
Library(Library),
}Expand description
Variants
Program(Program)
The source code which was parsed produced a valid Program, i.e. it contained a root module, and optionally, one or more library modules.
Library(Library)