pub struct TraceBinding {
pub span: SourceSpan,
pub name: Option<Identifier>,
pub segment: TraceSegmentId,
pub offset: usize,
pub size: usize,
pub ty: Type,
}Expand description
TraceBinding is used to represent one or more columns in the execution trace that are bound to a name. For single columns, the size is 1. For groups, the size is the number of columns in the group. The offset is the column index in the trace where the first column of the binding starts.
Fields
span: SourceSpanname: Option<Identifier>The name of this binding, if applicable
segment: TraceSegmentIdThe id of the segment to which this binding belongs
offset: usizeThe offset to the first column of the segment which is bound by this binding
size: usizeThe number of columns which are bound
ty: TypeThe effective type of this binding
Implementations
Sourceimpl TraceBinding
impl TraceBinding
Sourcepub const fn new(
span: SourceSpan,
name: Identifier,
segment: TraceSegmentId,
offset: usize,
size: usize,
ty: Type,
) -> Self
pub const fn new( span: SourceSpan, name: Identifier, segment: TraceSegmentId, offset: usize, size: usize, ty: Type, ) -> Self
Creates a new trace binding.
Sourcepub fn ty(&self) -> Type
pub fn ty(&self) -> Type
Returns a Type that describes what type of value this binding represents
pub fn is_scalar(&self) -> bool
Sourcepub fn access(
&self,
access_type: AccessType,
) -> Result<Self, InvalidAccessError>
pub fn access( &self, access_type: AccessType, ) -> Result<Self, InvalidAccessError>
Derive a new TraceBinding derived from the current one given an AccessType